@@ -9,15 +9,20 @@
 #include "addhostdialog.h"
 
 #include "kldapcore/ldapserver.h"
+#include "kldapwidgets/ldapactivitiesabstractplugin.h"
 #include "kldapwidgets/ldapconfigwidget.h"
 #include <KAcceleratorManager>
 #include <KConfigGroup>
 #include <KLocalizedString>
+#include <KPluginFactory>
+#include <KPluginMetaData>
 #include <KSharedConfig>
 #include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QPushButton>
+#include <QTabBar>
+#include <QTabWidget>
 #include <QVBoxLayout>
 #include <QWindow>
 
@@ -42,6 +47,8 @@ public:
     KLDAPCore::LdapServer *mServer = nullptr;
     QPushButton *mOkButton = nullptr;
     AddHostDialog *const q;
+    QTabWidget *mTabWidget = nullptr;
+    KLDAPWidgets::LdapActivitiesAbstractPlugin *mActivitiesPlugin = nullptr;
 };
 
 void AddHostDialog::readConfig()
@@ -76,11 +83,33 @@ AddHostDialog::AddHostDialog(KLDAPCore::LdapServer *server, QWidget *parent)
 
     d->mServer = server;
 
+    d->mTabWidget = new QTabWidget(this);
+    mainLayout->addWidget(d->mTabWidget);
+    d->mTabWidget->tabBar()->setExpanding(true);
+    d->mTabWidget->setDocumentMode(true);
+    d->mTabWidget->setTabBarAutoHide(true);
+
     auto page = new QWidget(this);
-    mainLayout->addWidget(page);
+    d->mTabWidget->addTab(page, i18n("Configure"));
+
+    const KPluginMetaData editWidgetPlugin(QStringLiteral("pim6/ldapactivities/kldapactivitiesplugin"));
+
+    const auto result = KPluginFactory::instantiatePlugin<KLDAPWidgets::LdapActivitiesAbstractPlugin>(editWidgetPlugin);
+    if (result) {
+        d->mActivitiesPlugin = result.plugin;
+    }
+    if (d->mActivitiesPlugin) {
+        d->mTabWidget->addTab(d->mActivitiesPlugin, i18n("Activities"));
+        KLDAPWidgets::LdapActivitiesAbstractPlugin::ActivitySettings settings{
+            d->mServer->activities(),
+            d->mServer->enablePlasmaActivities(),
+        };
+        d->mActivitiesPlugin->setActivitiesSettings(settings);
+    }
+
     mainLayout->addWidget(buttonBox);
     auto layout = new QHBoxLayout(page);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
 
     d->mCfg = new KLDAPWidgets::LdapConfigWidget(
         KLDAPWidgets::LdapConfigWidget::W_USER | KLDAPWidgets::LdapConfigWidget::W_PASS | KLDAPWidgets::LdapConfigWidget::W_BINDDN
@@ -176,6 +205,11 @@ void AddHostDialog::slotOk()
         d->mServer->setAuth(KLDAPCore::LdapServer::Anonymous);
     }
     d->mServer->setMech(d->mCfg->mech());
+    if (d->mActivitiesPlugin) {
+        const KLDAPWidgets::LdapActivitiesAbstractPlugin::ActivitySettings settings = d->mActivitiesPlugin->activitiesSettings();
+        d->mServer->setActivities(settings.activities);
+        d->mServer->setEnablePlasmaActivities(settings.enabled);
+    }
     QDialog::accept();
 }
 
