@@ -8,35 +8,36 @@
 
 #pragma once
 
-#include "kldap_export.h"
+#include "kldapwidgets_export.h"
 #include <QDialog>
 
-namespace KLDAP
+namespace KLDAPCore
 {
 class LdapServer;
+}
+namespace KLDAPWidgets
+{
 class AddHostDialogPrivate;
 /**
  * @brief The AddHostDialog class
  * @author Laurent Montel <montel@kde.org>
  */
-class KLDAP_EXPORT AddHostDialog : public QDialog
+class KLDAPWIDGETS_EXPORT AddHostDialog : public QDialog
 {
     Q_OBJECT
 
 public:
-    explicit AddHostDialog(KLDAP::LdapServer *server, QWidget *parent = nullptr);
+    explicit AddHostDialog(KLDAPCore::LdapServer *server, QWidget *parent = nullptr);
     ~AddHostDialog() override;
 
 Q_SIGNALS:
     void changed(bool);
 
-private Q_SLOTS:
-    void slotHostEditChanged(const QString &);
-    void slotOk();
-
 private:
-    void readConfig();
-    void writeConfig();
+    KLDAPWIDGETS_NO_EXPORT void slotHostEditChanged(const QString &);
+    KLDAPWIDGETS_NO_EXPORT void slotOk();
+    KLDAPWIDGETS_NO_EXPORT void readConfig();
+    KLDAPWIDGETS_NO_EXPORT void writeConfig();
     std::unique_ptr<AddHostDialogPrivate> const d;
 };
 }
