@@ -13,12 +13,14 @@
 class QTreeView;
 class QPushButton;
 class QToolButton;
+class QCheckBox;
 
 namespace KLDAPCore
 {
 class LdapClientSearchConfig;
 class LdapModel;
 class LdapSortProxyModel;
+class LdapActivitiesAbstract;
 }
 
 namespace KLDAPWidgets
@@ -35,6 +37,13 @@ public:
     ~LdapConfigureWidgetNg() override;
 
     void save();
+    void load();
+
+    [[nodiscard]] bool enablePlasmaActivities() const;
+    void setEnablePlasmaActivities(bool newEnablePlasmaActivities);
+
+    [[nodiscard]] KLDAPCore::LdapActivitiesAbstract *ldapActivitiesAbstract() const;
+    void setLdapActivitiesAbstract(KLDAPCore::LdapActivitiesAbstract *newldapActivitiesAbstract);
 
 Q_SIGNALS:
     void changed(bool);
@@ -43,7 +52,7 @@ private:
     KLDAPWIDGETS_NO_EXPORT void slotAddHost();
     KLDAPWIDGETS_NO_EXPORT void slotEditHost();
     KLDAPWIDGETS_NO_EXPORT void slotRemoveHost();
-    KLDAPWIDGETS_NO_EXPORT void slotSelectionChanged();
+    KLDAPWIDGETS_NO_EXPORT void updateButtons();
     KLDAPWIDGETS_NO_EXPORT void slotMoveUp();
     KLDAPWIDGETS_NO_EXPORT void slotMoveDown();
     KLDAPWIDGETS_NO_EXPORT void initGUI();
@@ -58,5 +67,6 @@ private:
     KLDAPCore::LdapClientSearchConfig *const mClientSearchConfig;
     KLDAPCore::LdapModel *const mLdapModel;
     KLDAPCore::LdapSortProxyModel *const mLdapSortProxyModel;
+    QCheckBox *const mLdapOnCurrentActivity;
 };
 }
